all.Amidihcrms<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--     \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------------\n")  
     cat("\n")
     note_for_close_window()
     AmidihcrMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),c=c(0))
     AmidihcrMSpar<-edit(AmidihcrMSpar)
##     AmidihcrMSpar<-ymscheck(AmidihcrMSpar)
     cat("\n")
     Amidihcr.ms(length(AmidihcrMSpar$subject),AmidihcrMSpar$c,AmidihcrMSpar$tau,AmidihcrMSpar$D,AmidihcrMSpar$ht,AmidihcrMSpar$age,AmidihcrMSpar$smoke,AmidihcrMSpar$Gender,AmidihcrMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--    \n")
     note_for_Thecr_output()
     cat("-------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.8,AmidihcrMSpar$D,AmidihcrMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     cal.again()                     
}